# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`grubby`](#grubby): Manage bootloader configuration via grubby
* [`grubby::config`](#grubbyconfig): Applies desired configuration via grubby

### Defined types

* [`grubby::kernel_opt`](#grubbykernel_opt): Applies kernel parameter configuration via grubby

### Data types

* [`Grubby::Kernel_Opts`](#grubbykernel_opts): Parameters for each kernel argument

## Classes

### <a name="grubby"></a>`grubby`

Manage bootloader configuration via grubby

#### Examples

##### Include Class

```puppet
include ::grubby
```

##### Specify Default Kernel

```puppet
class{'grubby:
  default_kernel => 'vmlinuz-4.18.0-240.15.1.el8_3.x86_64',
}
```

##### Add and Remove Kernel Options

```puppet
class{'grubby':
  kernel_opts => {
    audit  => {
      ensure => present,
      value  => 1,
      scope  => 'DEFAULT',
    },
    audit_backlog_limit => {
      value => 1,
    },
    selinux => {
      'ensure' => 'absent',
      'scope'  => 'ALL',
    }
  }
}
```

#### Parameters

The following parameters are available in the `grubby` class:

* [`default_kernel`](#default_kernel)
* [`kernel_opts`](#kernel_opts)

##### <a name="default_kernel"></a>`default_kernel`

Data type: `Optional[String[1]]`

The kernel version to set as default in the bootloader.

Default value: ``undef``

##### <a name="kernel_opts"></a>`kernel_opts`

Data type: `Optional[Hash[Pattern[/^\S+$/], Grubby::Kernel_Opts]]`

The kernel options that should be managed
for the default kernel
If ensure is not specified, present will be used (the other option being absent)
If scope is not specified, DEFAULT will be used (valid options are also ALL or specific kernel)
Example:
  audit:
    ensure: present
    value: 1
    scope: DEFAULT
  audit_backlog_limit:
    value: 8192
  selinux:
    ensure: absent
    scope: ALL
  enforcing:
    ensure: absent

Default value: `{}`

### <a name="grubbyconfig"></a>`grubby::config`

This is a private class, that performs the necessary changes via grubby

## Defined types

### <a name="grubbykernel_opt"></a>`grubby::kernel_opt`

Applies kernel parameter configuration via grubby

#### Examples

##### Add Single Parameter

```puppet
grubby::kernel_opt{'keyword':}
```

##### Delete a Single Parameter

```puppet
grubby::kernel_opt{'selinix':
  ensure => 'absent',
}
```

##### Add Parameter with Value

```puppet
grubby::kernel_opt{'memsize':
  value  => '22',
}
```

#### Parameters

The following parameters are available in the `grubby::kernel_opt` defined type:

* [`opt`](#opt)
* [`ensure`](#ensure)
* [`value`](#value)
* [`scope`](#scope)

##### <a name="opt"></a>`opt`

Data type: `Pattern[/^\S+$/]`

Kernel option

Default value: `$name`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

add or delete kernel option

Default value: `'present'`

##### <a name="value"></a>`value`

Data type: `Optional[Variant[Pattern[/^\S+$/],Integer]]`

Value of kernel option

Default value: ``undef``

##### <a name="scope"></a>`scope`

Data type: `Variant[Enum['DEFAULT','ALL'],Pattern[/^TITLE=.+$/]]`

Which kernels to apply parameters to

Default value: `'DEFAULT'`

## Data types

### <a name="grubbykernel_opts"></a>`Grubby::Kernel_Opts`

Parameters for each kernel argument

Alias of

```puppet
Struct[{
    Optional['ensure'] => Enum['present','absent'],
    Optional['value']  => Variant[Pattern[/^\S+$/],Integer],
    Optional['scope']  => Variant[Enum['DEFAULT','ALL'],Pattern[/^TITLE=.+$/]],
  }]
```

